Mynus, the minimalist wiki
==========================

The pupose of Mynus is to demonstrate the philosophy of "batteries included".
Thus, Mynus will never depends on anything else than the Python's standard
library.

Features
========

  * Provides a tiny wiki engine to launch everywhere.
  * No others dependencies than Python itself.
  * Offers a `mynus` script which allow you to transform any directory into a
    wiki repository.
  * WSGI Compliant.

License
=======

Mynus is released under the terms of the GNU Affero General Public License v3
or later.

TODO
====

  * Add showdown.js : http://attacklab.net/showdown/
  * Improve the mynus command line tool
  * Document the project
  * Make beautiful templates

